@@ -25,7 +25,6 @@ import os, os.path
 import data
 
 from myFunctions import *
-from myFunctions2 import *
 
 from Ui_StartWindow import *
 from Ui_CollectingWindow import *
@@ -306,9 +305,9 @@ def showGraph(self):
         for i in range(0,  data.arrDataIndex-shift-data.derivation,  Xscale):
             k=i+shift
             
-            #            mov=0
+#           #            mov=0
 #            peak=0
-#            for j in range(0, data.Xscale):
+#            for j in range(0, Xscale):
 #                if(data.arrData[5][i+j]==1):
 #                    mov=mov+1
 #                    x=(abs(data.arrData[3][i])+abs(data.arrData[4][i]))
@@ -329,17 +328,25 @@ def showGraph(self):
                 #fill space between yellow movement lines
 #                if(k>lastmove+1):k
                 if(peak>data.trigger):
-#                    1=10 sec
-                    if((i-lastmove)>30*Xscale): color="#009100" #green
-                    elif((i-lastmove)>15*Xscale): color="#005000" #dark green
-                    else: color="#6D0000" #dark red 
+##                    1=10 sec
+#                    if((i-lastmove)>30*Xscale): color="#009100" #green
+#                    elif((i-lastmove)>15*Xscale): color="#005000" #dark green
+#                    time=(i-lastmove)*Xscale
+#                    print time,  30*Xscale
+#                    if(time>30): color="#009100" #green
+#                    elif(time>15): color="#005000" #dark green
+#                    else: color="#6D0000" #dark red 
 
-                    paint.setBrush(QtGui.QColor(color))
-                    paint.setPen(QtGui.QColor(color))
                     x0=lastmove/Xscale+1
                     x1=i/Xscale-1
-#                    print x0,  "<=>",  x1
                     if(x0<x1):
+                        time=(x1-x0)*Xscale/6          
+                        print x0,  "<=>",  x1,  time,  Xscale
+                        if(time>30): color="#009100" #green
+                        elif(time>15): color="#005000" #dark green
+                        else: color="#6D0000" #dark red                         
+                        paint.setBrush(QtGui.QColor(color))
+                        paint.setPen(QtGui.QColor(color))
                         paint.drawRect(x0, data.Ysize-11, x1-x0, 10) 
 #                        print "=     Draw field",  x0,  x1,  data.Ysize,  color
                     lastmove=i
